@@ -581,7 +581,8 @@ class ProjectConfig(object):
                 lib,
                 self.config['arch'],
                 self.config['root_dir'],
-                self.debug_build
+                self.debug_build,
+                self.verbose
             ) for name, lib in self.config['libraries'].items()
         ]
 
@@ -625,7 +626,7 @@ class ProjectConfig(object):
         return self.config["builder"] in Constants.arch_agnostic_builders
 
     def is_desktop_mode(self):
-        return bool(set(['desktop', 'test', 'ide']).intersection(self.commands))
+        return bool(set(['desktop', 'test-libs', 'test', 'ide']).intersection(self.commands))
 
     def is_ide_command(self):
         return "ide" in self.commands
